import React from "react";
import { RefreshControl } from "react-native";
import { getPostsInterval, Post } from "../util/api";
import { PostView } from "./PostView";
import { style } from "../util/style";
import { SafeAreaView } from "react-native";
import { VirtualizedList } from "react-native";

export function PostsContainer(): JSX.Element {
  const [postData, setPostData] = React.useState<Post[]>([]);
  const [page, setPage] = React.useState<number>(0);
  const [refreshing, setRefreshing] = React.useState<boolean>(false);

  const handleEndReached = (): void => {
    setPage((prevPage) => prevPage + 1);
  };

  React.useEffect(() => {
    refreshPosts();
  }, [page]);

  function refreshPosts(): void {
    async function fetchPosts(): Promise<void> {
      const newPosts = await getPostsInterval(page*10, 10)
      setPostData((oldPosts: Post[]) => [...oldPosts, ...newPosts]);
    }
    fetchPosts();
  }

  function onRefresh(): void {
    setRefreshing(true);
    setPostData([]);
    setPage(0);
    setRefreshing(false);
  }

  // eslint-disable-next-line @typescript-eslint/no-unused-vars
  const getItemCount = (_data: unknown): number => postData.length;

  const getItem = (_data: unknown, index: number): Post => postData[index];
  return (
    <SafeAreaView style={style.postsContainer}>
      <VirtualizedList
        data={postData}
        initialNumToRender={4}
        renderItem={({ item }) => <PostView key={item.id} post={item} />}
        keyExtractor={(item: Post) => item.id}
        getItemCount={getItemCount}
        getItem={getItem}
        onEndReached={handleEndReached}
        onEndReachedThreshold={0.4}
        refreshControl={
          <RefreshControl
            refreshing={refreshing}
            onRefresh={onRefresh}
            colors={["#007AFF"]}
          />
        }
      />
    </SafeAreaView>
  );
}
